@@ -1,10 +1,10 @@
-# @(#)$Id: FormWidgets.pm 334 2011-12-12 04:30:18Z pjf $
+# @(#)$Id: FormWidgets.pm 336 2011-12-30 00:08:12Z pjf $
 
 package HTML::FormWidgets;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 334 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 336 $ =~ /\d+/gmx );
 use parent qw(Class::Accessor::Fast);
 
 use Class::MOP;
@@ -169,12 +169,11 @@ sub add_literal_js {
       if ($k) { $list and $list .= ', '; $list .= $k.': '.($v || 'null') }
    }
 
-   my $text  = $self->options->{js_object};
-      $text .= ".config.${js_class}[ '${id}' ] = { ${list} };";
+   my $obj = $self->options->{js_object}; $self->options->{literal_js} ||= [];
 
-   $self->options->{literal_js} ||= [];
+   push @{ $self->options->{literal_js} },
+      "${obj}.config.${js_class}[ '${id}' ] = { ${list} };";
 
-   push @{ $self->options->{literal_js} }, $text;
    return;
 }
 
@@ -488,7 +487,7 @@ HTML::FormWidgets - Create HTML user interface components
 
 =head1 Version
 
-0.8.$Rev: 334 $
+0.9.$Rev: 336 $
 
 =head1 Synopsis
 
@@ -791,6 +790,13 @@ arg (which defaults to B<linkFade>). It's I<href> attribute
 set to the I<href> arg. The anchor body is set to the I<text>
 arg
 
+=head2 Async
+
+Returns a C<< <div> >> element with a class set from the I<class> arg
+(which defaults to B<server>). The div body is set to the I<text>
+arg. When the JS onload event handler fires it will asynchronously
+load the content of the div if it is visible
+
 =head2 Button
 
 Generates an image button where I<name> identifies the image
